@@ -1,8 +1,7 @@
 /**********************************************************************
- * $Id: example.cpp 2207 2008-10-22 18:51:09Z pramsey $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  * Copyright (C) 2005 Refractions Research Inc.
@@ -28,10 +27,6 @@
  *
  **********************************************************************/
 
-#include <vector>
-#include <sstream>
-#include <iomanip>
-#include <cstdlib>
 #include <geos/geom/PrecisionModel.h>
 #include <geos/geom/GeometryFactory.h>
 #include <geos/geom/Geometry.h>
@@ -48,10 +43,15 @@
 #include <geos/io/WKBWriter.h>
 #include <geos/io/WKTWriter.h>
 #include <geos/util/GeometricShapeFactory.h>
+#include <geos/geom/util/SineStarFactory.h>
 #include <geos/util/GEOSException.h>
 #include <geos/util/IllegalArgumentException.h>
 #include <geos/opLinemerge.h>
 #include <geos/opPolygonize.h>
+#include <vector>
+#include <sstream>
+#include <iomanip>
+#include <cstdlib> // exit()
 
 #ifndef M_PI
 #define M_PI       3.14159265358979323846
@@ -71,6 +71,8 @@ using namespace geos;
 using namespace geos::geom;
 using namespace geos::operation::polygonize;
 using namespace geos::operation::linemerge;
+using geos::util::GEOSException;
+using geos::util::IllegalArgumentException;
 
 
 // Prototypes
@@ -82,7 +84,7 @@ void wkt_print_geoms(vector<Geometry *> *geoms);
 // but that would be boring because you'd need to specify
 // a PrecisionModel and a SRID everytime: those infos are
 // cached inside a GeometryFactory object.
-GeometryFactory *global_factory;
+GeometryFactory::unique_ptr global_factory;
 
 //#define DEBUG_STREAM_STATE 1
 
@@ -333,7 +335,7 @@ create_simple_collection(vector<Geometry *> *geoms)
 Polygon *
 create_circle(double centerX, double centerY, double radius)
 {
-	util::GeometricShapeFactory shapefactory(global_factory);
+	geos::util::GeometricShapeFactory shapefactory(global_factory.get());
 	shapefactory.setCentre(Coordinate(centerX, centerY));
 	shapefactory.setSize(radius);
 	// same as:
@@ -349,7 +351,7 @@ create_circle(double centerX, double centerY, double radius)
 Polygon *
 create_ellipse(double centerX, double centerY, double width, double height)
 {
-	util::GeometricShapeFactory shapefactory(global_factory);
+	geos::util::GeometricShapeFactory shapefactory(global_factory.get());
 	shapefactory.setCentre(Coordinate(centerX, centerY));
 	shapefactory.setHeight(height);
 	shapefactory.setWidth(width);
@@ -364,7 +366,7 @@ create_ellipse(double centerX, double centerY, double width, double height)
 Polygon *
 create_rectangle(double llX, double llY, double width, double height)
 {
-	util::GeometricShapeFactory shapefactory(global_factory);
+	geos::util::GeometricShapeFactory shapefactory(global_factory.get());
 	shapefactory.setBase(Coordinate(llX, llY));
 	shapefactory.setHeight(height);
 	shapefactory.setWidth(width);
@@ -381,7 +383,7 @@ create_rectangle(double llX, double llY, double width, double height)
 LineString *
 create_arc(double llX, double llY, double width, double height, double startang, double endang)
 {
-	util::GeometricShapeFactory shapefactory(global_factory);
+	geos::util::GeometricShapeFactory shapefactory(global_factory.get());
 	shapefactory.setBase(Coordinate(llX, llY));
 	shapefactory.setHeight(height);
 	shapefactory.setWidth(width);
@@ -390,6 +392,18 @@ create_arc(double llX, double llY, double width, double height, double startang,
 	return shapefactory.createArc(startang, endang);
 }
 
+auto_ptr<Polygon>
+create_sinestar(double cx, double cy, double size, int nArms, double armLenRat)
+{
+	geos::geom::util::SineStarFactory fact(global_factory.get());
+	fact.setCentre(Coordinate(cx, cy));
+	fact.setSize(size);
+	fact.setNumPoints(nArms*5);
+  fact.setArmLengthRatio(armLenRat);
+	fact.setNumArms(nArms);
+	return fact.createSineStar();
+}
+
 // Start reading here
 void do_all()
 {
@@ -402,7 +416,7 @@ void do_all()
 
 	// Initialize global factory with defined PrecisionModel
 	// and a SRID of -1 (undefined).
-	global_factory = new GeometryFactory(pm, -1);
+	global_factory = GeometryFactory::create(pm, -1);
 
 	// We do not need PrecisionMode object anymore, it has
 	// been copied to global_factory private storage
@@ -429,6 +443,7 @@ void do_all()
 	geoms->push_back(create_rectangle(-5, -5, 10, 20)); // a rectangle
 	// The upper-right quarter of a vertical ellipse
 	geoms->push_back(create_arc(0, 0, 10, 20, 0, M_PI/2));
+	geoms->push_back(create_sinestar(10, 10, 100, 5, 2).release()); // a sine star
 #endif
 
 	// Print all geoms.
@@ -474,7 +489,7 @@ void do_all()
 			Geometry *g2 = g->buffer(10);
 			newgeoms->push_back(g2);
 		}
-		catch (const util::GEOSException& exc) {
+		catch (const GEOSException& exc) {
 			cerr <<"GEOS Exception: geometry "<<i<<"->buffer(10): "<<exc.what()<<"\n";
 		}
 	}
@@ -540,7 +555,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -570,7 +585,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -600,7 +615,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -630,7 +645,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -660,7 +675,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -690,7 +705,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -720,7 +735,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -757,7 +772,7 @@ cout<<"-------------------------------------------------------------------------
 				delete im; // delete afterwards
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -787,7 +802,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -818,7 +833,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -849,7 +864,7 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (const util::IllegalArgumentException& exc) {
+			catch (const IllegalArgumentException& exc) {
 				cout<<" X\t";
 			}
 			catch (const std::exception& exc) {
@@ -887,7 +902,7 @@ cout<<"-------------------------------------------------------------------------
 				newgeoms->push_back(g3);
 			}
 			// It's illegal to union a collection ...
-			catch (const util::IllegalArgumentException& ill) {
+			catch (const IllegalArgumentException& ill) {
 				//cerr <<ill.toString()<<"\n";
 			}
 			catch (const std::exception& exc) {
@@ -922,7 +937,7 @@ cout<<"-------------------------------------------------------------------------
 				newgeoms->push_back(g3);
 			}
 			// Collection are illegal as intersection argument
-			catch (const util::IllegalArgumentException& ill) {
+			catch (const IllegalArgumentException& ill) {
 				//cerr <<ill.toString()<<"\n";
 			}
 			catch (const std::exception& exc) {
@@ -955,7 +970,7 @@ cout<<"-------------------------------------------------------------------------
 				newgeoms->push_back(g3);
 			}
 			// Collection are illegal as difference argument
-			catch (const util::IllegalArgumentException& ill) {
+			catch (const IllegalArgumentException& ill) {
 				//cerr <<ill.toString()<<"\n";
 			}
 			catch (const std::exception& exc) {
@@ -988,7 +1003,7 @@ cout<<"-------------------------------------------------------------------------
 				newgeoms->push_back(g3);
 			}
 			// Collection are illegal as symdifference argument
-			catch (const util::IllegalArgumentException& ill) {
+			catch (const IllegalArgumentException& ill) {
 				//cerr <<ill.toString()<<"\n";
 			}
 			catch (const std::exception& exc) {
@@ -1065,8 +1080,6 @@ cout<<"-------------------------------------------------------------------------
 		delete (*geoms)[i];
 	}
 	delete geoms;
-
-	delete global_factory;
 }
 
 int
@@ -1079,7 +1092,7 @@ main()
 	}
 	// All exception thrown by GEOS are subclasses of this
 	// one, so this is a catch-all 
-	catch (const util::GEOSException& exc)
+	catch (const GEOSException& exc)
 	{
 		cerr <<"GEOS Exception: "<<exc.what()<<"\n";
 		exit(1);
@@ -1101,114 +1114,3 @@ main()
 
 	exit(0);
 }
-
-/**********************************************************************
- * $Log$
- * Revision 1.46  2006/04/09 11:07:54  mloskot
- * Small fixes in doc/example.cpp.
- *
- * Revision 1.45  2006/04/04 08:16:46  strk
- * Changed GEOSException hierarchy to be derived from std::runtime_exception.
- * Removed the GEOSException::toString redundant method (use ::what() instead)
- *
- * Revision 1.44  2006/03/28 15:19:22  strk
- * Added macros for sections skip (useful in debugging)
- *
- * Revision 1.43  2006/03/15 18:44:51  strk
- * Bug #60 - Missing <cmath> header in some files
- *
- * Revision 1.42  2006/03/06 21:27:39  strk
- * Cascading fixed after Unload definition moved to geos::io namespace
- *
- * Revision 1.41  2006/03/06 19:40:46  strk
- * geos::util namespace. New GeometryCollection::iterator interface, many cleanups.
- *
- * Revision 1.40  2006/03/06 15:23:14  strk
- * geos::io namespace
- *
- * Revision 1.39  2006/03/03 10:46:21  strk
- * Removed 'using namespace' from headers, added missing headers in .cpp files, removed useless includes in headers (bug#46)
- *
- * Revision 1.38  2006/02/19 19:46:49  strk
- * Packages <-> namespaces mapping for most GEOS internal code (uncomplete, but working). Dir-level libs for index/ subdirs.
- *
- * Revision 1.37  2006/02/09 15:52:47  strk
- * GEOSException derived from std::exception; always thrown and cought by const ref.
- *
- * Revision 1.36  2006/01/31 19:07:33  strk
- * - Renamed DefaultCoordinateSequence to CoordinateArraySequence.
- * - Moved GetNumGeometries() and GetGeometryN() interfaces
- *   from GeometryCollection to Geometry class.
- * - Added getAt(int pos, Coordinate &to) funtion to CoordinateSequence class.
- * - Reworked automake scripts to produce a static lib for each subdir and
- *   then link all subsystem's libs togheter
- * - Moved C-API in it's own top-level dir capi/
- * - Moved source/bigtest and source/test to tests/bigtest and test/xmltester
- * - Fixed PointLocator handling of LinearRings
- * - Changed CoordinateArrayFilter to reduce memory copies
- * - Changed UniqueCoordinateArrayFilter to reduce memory copies
- * - Added CGAlgorithms::isPointInRing() version working with
- *   Coordinate::ConstVect type (faster!)
- * - Ported JTS-1.7 version of ConvexHull with big attention to
- *   memory usage optimizations.
- * - Improved XMLTester output and user interface
- * - geos::geom::util namespace used for geom/util stuff
- * - Improved memory use in geos::geom::util::PolygonExtractor
- * - New ShortCircuitedGeometryVisitor class
- * - New operation/predicate package
- *
- * Revision 1.35  2005/11/30 11:27:07  strk
- * catch std::exception by ref
- *
- * Revision 1.34  2005/11/30 11:25:12  strk
- * includes cleanup
- *
- * Revision 1.33  2005/09/27 16:20:43  strk
- * Reverted previous change, fixed the bug by turning WKBReader.factory
- * into a reference rather then a real object. ABI still breaks, but API
- * at least is safe (we didn't release any WKB-aware package so breaking
- * ABI is not a big deal at this stage).
- *
- * Revision 1.32  2005/09/27 16:00:26  strk
- * Fixed bug in WKBReader destroying the GeometryFactory used in Geometry
- * construction. Changed it's definition to *require* a GeometryFactory
- * pointer parameter.
- *
- * Revision 1.31  2005/09/26 08:17:19  strk
- * Removed memory leak from WKB tester
- *
- * Revision 1.30  2005/09/03 21:26:42  strk
- * Reworked WKB I/O to avoid use of templates and make better use of STL
- *
- * Revision 1.29  2005/07/11 12:17:26  strk
- * Commented out useless include
- *
- * Revision 1.28  2005/04/29 16:36:28  strk
- * Made WKBReader use global_factory, for having WKB reads produce
- * same context of input geoms.
- *
- * Revision 1.27  2005/04/29 15:34:20  strk
- * Typedef'ed biostringstream, preferred parameter for
- * WKB parser templates.
- * Added << operator for biostringstream.
- * Typedef'ed WKBWriter and WKBReader to be parametrized by
- * biostringstream.
- * Added WKBtest in doc/example.cpp
- *
- * Revision 1.26  2004/12/08 13:54:43  strk
- * gcc warnings checked and fixed, general cleanups.
- *
- * Revision 1.25  2004/10/13 10:03:02  strk
- * Added missing linemerge and polygonize operation.
- * Bug fixes and leaks removal from the newly added modules and
- * planargraph (used by them).
- * Some comments and indentation changes.
- *
- * Revision 1.24  2004/07/22 16:58:01  strk
- * runtime version extractor functions split. geos::version() is now
- * geos::geosversion() and geos::jtsport()
- *
- * Revision 1.23  2004/07/17 09:19:32  strk
- * added GEOS version report
- *
- *********************************************************************/
