@@ -79,7 +79,7 @@ Geometry *ExtractLineByLocation::reverse(const Geometry *linear)
 		}
 		else
 		{
-			assert(!"non-linear geometry encountered");
+			assert(!static_cast<bool>("non-linear geometry encountered"));
             return 0;
 		}
 	}
